summaryrefslogtreecommitdiffstats
path: root/apps/beats-time/app.c
diff options
context:
space:
mode:
authorJoey Castillo <jose.castillo@gmail.com>2021-10-20 13:45:22 -0400
committerJoey Castillo <jose.castillo@gmail.com>2021-10-20 13:45:22 -0400
commit38a2dff23491c4b22a8e55ffd6d096a198857c9f (patch)
tree2d3f87c41f0dbea12d2122defb2bf456acc7467c /apps/beats-time/app.c
parent1020dd78981e0d4b4f20399aa5e76ea7d37beec6 (diff)
downloadSensor-Watch-38a2dff23491c4b22a8e55ffd6d096a198857c9f.tar.gz
Sensor-Watch-38a2dff23491c4b22a8e55ffd6d096a198857c9f.tar.bz2
Sensor-Watch-38a2dff23491c4b22a8e55ffd6d096a198857c9f.zip
more accurate names for deep sleep and shallow sleep modes
Diffstat (limited to 'apps/beats-time/app.c')
-rw-r--r--apps/beats-time/app.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/apps/beats-time/app.c b/apps/beats-time/app.c
index 611e7f16..5c68a3e8 100644
--- a/apps/beats-time/app.c
+++ b/apps/beats-time/app.c
@@ -50,8 +50,8 @@ void app_init() {
memset(&application_state, 0, sizeof(application_state));
}
-void app_wake_from_deep_sleep() {
- // This app does not support deep sleep mode.
+void app_wake_from_backup() {
+ // This app does not support BACKUP mode.
}
void app_setup() {
@@ -67,10 +67,10 @@ void app_setup() {
watch_rtc_register_tick_callback(cb_tick);
}
-void app_prepare_for_sleep() {
+void app_prepare_for_standby() {
}
-void app_wake_from_sleep() {
+void app_wake_from_standby() {
}
void update_tick_frequency() {